import React, { useState } from 'react';
import { motion } from 'framer-motion';
import { 
  Server, 
  Database, 
  Lock,
  BarChart as ChartBar,
  DollarSign,
  Clock,
  CheckCircle2,
  Shield,
  Zap,
  Cloud,
  TrendingUp,
  Users,
  Brain,
  Microscope,
  LineChart,
  Send,
  Loader2,
  AlertCircle
} from 'lucide-react';
import { Link, useNavigate } from 'react-router-dom';
import Layout from '../components/Layout';
import AnimatedSection from '../components/AnimatedSection';
import CaseStudyCarousel from '../components/CaseStudyCarousel';
import LazyImage from '../components/LazyImage';
import { useToast } from '../hooks/useToast';
import { isWorkEmail } from '../utils/validation';

const Home = () => {
  const navigate = useNavigate();
  const [formData, setFormData] = useState({
    email: '',
    firstName: '',
    lastName: '',
    phone: ''
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [emailError, setEmailError] = useState<string | null>(null);
  const { addToast } = useToast();

  const handleEmailChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const email = e.target.value;
    setFormData(prev => ({ ...prev, email }));
    
    if (email && !isWorkEmail(email)) {
      setEmailError('Please use your work email address');
    } else {
      setEmailError(null);
    }
  };

  const handleSubscribe = async (e: React.FormEvent) => {
    e.preventDefault();
    
    if (!formData.email || !formData.email.includes('@')) {
      addToast('Please enter a valid email address', 'error');
      return;
    }

    if (!isWorkEmail(formData.email)) {
      addToast('Please use your work email address', 'error');
      return;
    }

    setIsSubmitting(true);
    try {
      // Create FormData object
      const form = e.target as HTMLFormElement;
      const formData = new FormData(form);
      
      // Add form name to ensure Netlify processes it correctly
      formData.append('form-name', 'subscribe');

      // Submit to Netlify
      const response = await fetch('/', {
        method: 'POST',
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
        body: new URLSearchParams(formData as any).toString()
      });

      if (!response.ok) {
        throw new Error('Failed to submit form');
      }

      // Set success flag in session storage
      sessionStorage.setItem('formSubmitted', 'true');
      
      addToast('Thank you for subscribing! We\'ll be in touch soon.', 'success');
      setFormData({
        email: '',
        firstName: '',
        lastName: '',
        phone: ''
      });
      setEmailError(null);
      
      // Navigate to success page
      navigate('/success?form=subscribe');
    } catch (error) {
      console.error('Subscription error:', error);
      addToast('Failed to subscribe. Please try again.', 'error');
    } finally {
      setIsSubmitting(false);
    }
  };

  const caseStudies = [
    {
      title: "BioTech Startup Cost Reduction",
      description: "Helped a growing biotech startup reduce IT costs by 40% while improving system reliability and security.",
      metrics: [
        { icon: <DollarSign className="h-5 w-5" />, value: "$450K", label: "Annual Savings" },
        { icon: <Clock className="h-5 w-5" />, value: "99.9%", label: "Uptime" },
        { icon: <ChartBar className="h-5 w-5" />, value: "3x", label: "Efficiency Gain" }
      ],
      image: "https://images.unsplash.com/photo-1532187863486-abf9dbad1b69?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Research Lab Infrastructure Upgrade",
      description: "Modernized legacy systems for a research lab, resulting in faster data processing and enhanced security.",
      metrics: [
        { icon: <Clock className="h-5 w-5" />, value: "75%", label: "Faster Processing" },
        { icon: <DollarSign className="h-5 w-5" />, value: "$300K", label: "Cost Savings" },
        { icon: <CheckCircle2 className="h-5 w-5" />, value: "100%", label: "Compliance" }
      ],
      image: "https://images.unsplash.com/photo-1581093450021-4a7360e9a6b5?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Pharmaceutical Cloud Migration",
      description: "Led a seamless cloud migration for a pharmaceutical company, enhancing data accessibility while maintaining strict security.",
      metrics: [
        { icon: <Cloud className="h-5 w-5" />, value: "100%", label: "Cloud Adoption" },
        { icon: <Shield className="h-5 w-5" />, value: "Zero", label: "Security Incidents" },
        { icon: <DollarSign className="h-5 w-5" />, value: "$600K", label: "Annual Savings" }
      ],
      image: "https://images.unsplash.com/photo-1576086213369-97a306d36557?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Clinical Trials Tech Optimization",
      description: "Streamlined clinical trials technology infrastructure, reducing data processing time and improving trial efficiency.",
      metrics: [
        { icon: <Zap className="h-5 w-5" />, value: "60%", label: "Faster Trials" },
        { icon: <TrendingUp className="h-5 w-5" />, value: "40%", label: "More Trials" },
        { icon: <DollarSign className="h-5 w-5" />, value: "$800K", label: "Cost Reduction" }
      ],
      image: "https://images.unsplash.com/photo-1584362917165-526a968579e8?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Genomics Research Acceleration",
      description: "Implemented high-performance computing solutions for a genomics research institute, dramatically reducing analysis time.",
      metrics: [
        { icon: <Brain className="h-5 w-5" />, value: "90%", label: "Faster Analysis" },
        { icon: <Users className="h-5 w-5" />, value: "3x", label: "User Capacity" },
        { icon: <DollarSign className="h-5 w-5" />, value: "$750K", label: "Cost Savings" }
      ],
      image: "https://images.unsplash.com/photo-1614935151651-0bea6508db6b?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Lab Equipment Integration",
      description: "Developed a unified system for managing and monitoring advanced lab equipment across multiple facilities.",
      metrics: [
        { icon: <Microscope className="h-5 w-5" />, value: "100%", label: "Integration" },
        { icon: <LineChart className="h-5 w-5" />, value: "85%", label: "Efficiency Gain" },
        { icon: <Clock className="h-5 w-5" />, value: "24/7", label: "Monitoring" }
      ],
      image: "https://images.unsplash.com/photo-1582719471384-894fbb16e074?auto=format&fit=crop&q=80&w=1920"
    },
    {
      title: "Biotech Data Security Enhancement",
      description: "Implemented comprehensive security measures for a biotech firm handling sensitive research data.",
      metrics: [
        { icon: <Shield className="h-5 w-5" />, value: "100%", label: "Compliance" },
        { icon: <Clock className="h-5 w-5" />, value: "-65%", label: "Response Time" },
        { icon: <DollarSign className="h-5 w-5" />, value: "$500K", label: "Risk Mitigation" }
      ],
      image: "https://images.unsplash.com/photo-1563986768609-322da13575f3?auto=format&fit=crop&q=80&w=1920"
    }
  ];

  return (
    <Layout>
      {/* Hero Section */}
      <AnimatedSection className="relative bg-gray-900 text-white -mt-24 pt-40 pb-24">
        <div className="absolute inset-0">
          <LazyImage
            src="https://images.unsplash.com/photo-1451187580459-43490279c0fa?auto=format&fit=crop&q=80&w=1920"
            alt="Digital Transformation"
            className="w-full h-full object-cover opacity-10"
            sizes="100vw"
            fetchpriority="high"
          />
        </div>
        <div className="relative text-center">
          <h1 className="text-4xl md:text-6xl font-bold mb-6">
            Efficient & Secure Bio-Tech IT Operations
          </h1>
          <p className="text-xl md:text-2xl mb-8 max-w-3xl mx-auto">
            I help bio-tech companies achieve up to $1 million in annual cost savings through efficient IT operations.
          </p>
          
          {/* Enhanced Subscription Form */}
          <form 
            name="subscribe"
            method="POST"
            data-netlify="true"
            data-netlify-honeypot="bot-field"
            action="/success?form=subscribe"
            onSubmit={handleSubscribe}
            className="max-w-lg mx-auto bg-white rounded-lg shadow-xl p-6"
          >
            {/* Hidden fields for Netlify */}
            <input type="hidden" name="form-name" value="subscribe" />
            <div hidden>
              <input name="bot-field" />
            </div>

            <h3 className="text-gray-900 font-semibold text-xl mb-4">Subscribe to Learn More</h3>
            <div className="grid grid-cols-1 sm:grid-cols-2 gap-4 mb-4">
              <div>
                <input
                  type="text"
                  name="firstName"
                  placeholder="First Name"
                  value={formData.firstName}
                  onChange={(e) => setFormData(prev => ({ ...prev, firstName: e.target.value }))}
                  className="w-full px-4 py-2 rounded-lg border border-gray-300 focus:ring-2 focus:ring-teal-500 focus:border-transparent"
                />
              </div>
              <div>
                <input
                  type="text"
                  name="lastName"
                  placeholder="Last Name"
                  value={formData.lastName}
                  onChange={(e) => setFormData(prev => ({ ...prev, lastName: e.target.value }))}
                  className="w-full px-4 py-2 rounded-lg border border-gray-300 focus:ring-2 focus:ring-teal-500 focus:border-transparent"
                />
              </div>
            </div>
            <div className="mb-4">
              <div className="relative">
                <input
                  type="email"
                  name="email"
                  placeholder="Work Email"
                  value={formData.email}
                  onChange={handleEmailChange}
                  className={`w-full px-4 py-2 rounded-lg border focus:ring-2 focus:ring-teal-500 focus:border-transparent ${
                    emailError ? 'border-red-300' : 'border-gray-300'
                  }`}
                  required
                />
                {emailError && (
                  <div className="absolute -bottom-6 left-0 flex items-center text-sm text-red-600">
                    <AlertCircle className="h-4 w-4 mr-1" />
                    {emailError}
                  </div>
                )}
              </div>
            </div>
            <div className="mb-4">
              <input
                type="tel"
                name="phone"
                placeholder="Phone Number"
                value={formData.phone}
                onChange={(e) => setFormData(prev => ({ ...prev, phone: e.target.value }))}
                className="w-full px-4 py-2 rounded-lg border border-gray-300 focus:ring-2 focus:ring-teal-500 focus:border-transparent"
              />
            </div>
            <button
              type="submit"
              disabled={isSubmitting || !!emailError}
              className="w-full px-6 py-3 bg-teal-600 hover:bg-teal-700 rounded-lg text-white font-medium transition-colors duration-200 disabled:opacity-50 disabled:cursor-not-allowed flex items-center justify-center"
            >
              {isSubmitting ? (
                <Loader2 className="h-5 w-5 animate-spin" />
              ) : (
                <>
                  <Send className="h-5 w-5 mr-2" />
                  Subscribe to Learn More
                </>
              )}
            </button>
            <p className="text-xs text-gray-500 mt-2">
              By subscribing, you agree to our{' '}
              <Link to="/privacy-policy" className="text-teal-600 hover:text-teal-700">
                Privacy Policy
              </Link>
            </p>
          </form>
        </div>
      </AnimatedSection>

      {/* BioPulse360 Section */}
      <AnimatedSection className="py-20 bg-teal-50" delay={0.4}>
        <div className="text-center mb-16">
          <div className="flex justify-center space-x-4 mb-6">
            <Server className="h-16 w-16 text-teal-600" />
            <Database className="h-16 w-16 text-teal-600" />
            <Lock className="h-16 w-16 text-teal-600" />
          </div>
          <h2 className="text-3xl font-bold text-gray-900 mb-4">Introducing BioPulse360™ Services</h2>
          <p className="text-xl text-gray-600 max-w-3xl mx-auto mb-8">
            Comprehensive IT services tailored for biotech companies. Our specialized service suite 
            helps you streamline operations, ensure compliance, and accelerate innovation through 
            expert technology management.
          </p>
          <Link
            to="/early-access"
            className="group inline-flex items-center px-8 py-4 bg-white text-teal-600 border-2 border-teal-600 rounded-lg shadow-lg transition-all duration-300 hover:bg-teal-50 hover:shadow-xl"
          >
            <span className="font-semibold text-lg">
              Join Priority Access List
            </span>
            <Send className="ml-2 h-6 w-6 transition-transform duration-300 group-hover:translate-x-1" />
          </Link>
        </div>
      </AnimatedSection>

      {/* Case Studies Section */}
      <AnimatedSection className="py-20 bg-white" delay={0.5}>
        <div className="text-center mb-16">
          <h2 className="text-3xl font-bold text-gray-900 mb-4">Success Stories</h2>
          <p className="text-xl text-gray-600 max-w-3xl mx-auto">
            Real results from real biotech companies
          </p>
        </div>

        <CaseStudyCarousel studies={caseStudies} />
      </AnimatedSection>

      {/* CTA Section */}
      <AnimatedSection className="bg-teal-600 py-16" delay={0.6}>
        <div className="text-center">
          <h2 className="text-3xl font-bold text-white mb-4">
            Ready to transform your biotech operations?
          </h2>
          <p className="text-teal-100 mb-8 max-w-2xl mx-auto">
            Let's discuss how we can help you achieve your technology goals.
          </p>
          <div className="space-y-4">
            <Link
              to="/early-access"
              className="inline-flex items-center px-6 py-3 bg-white text-teal-600 hover:bg-gray-100 hover:text-teal-700 rounded-lg transition-colors duration-200"
            >
              Contact Us
              <Send className="ml-2 h-5 w-5" />
            </Link>
            <div className="text-teal-100">
              or call us at{' '}
              <a 
                href="tel:+16892024483" 
                className="text-white font-semibold hover:text-teal-100 transition-colors"
              >
                (689) 202-4483
              </a>
            </div>
          </div>
        </div>
      </AnimatedSection>
    </Layout>
  );
};

export default Home;